@@ -1,5 +1,9 @@
+{-# LANGUAGE DeriveGeneric #-}
+
 module Test.Tasty.Patterns.Types where
 
+import GHC.Generics
+
 data Expr
   = IntLit !Int
   | NF -- ^ number of fields
@@ -27,4 +31,4 @@ data Expr
   | LengthFn (Maybe Expr)
   | MatchFn Expr String
   | SubstrFn Expr Expr (Maybe Expr)
-  deriving (Show, Eq)
+  deriving (Show, Eq, Generic)
